# eric7.Plugins.VcsPlugins.vcsMercurial.HgUtilities

Module implementing some common utility functions for the Mercurial package.

### Global Attributes

None

### Classes

None

### Functions

getConfigPath | Function to get the filename of the config file.
getHgExecutable | Function to get the full path of the Mercurial executable.
hgVersion | Public method to determine the Mercurial version.
prepareProcess | Function to prepare the given process.

## getConfigPath

getConfigPath()

Function to get the filename of the config file.

Return:
  filename of the config file

Return Type:
  str

Up

## getHgExecutable

getHgExecutable()

Function to get the full path of the Mercurial executable.

Return:
  path of the Mercurial executable

Return Type:
  str

Up

## hgVersion

hgVersion(plugin)

Public method to determine the Mercurial version.

plugin (VcsMercurialPlugin)
  reference to the plugin object

Return:
  tuple containing the Mercurial version as a string and as a tuple and an error message.

Return Type:
  tuple of str, tuple of int and str

Up

## prepareProcess

prepareProcess(proc, encoding="", language="")

Function to prepare the given process.

proc (QProcess)
  reference to the process to be prepared
encoding (str)
  encoding to be used by the process
language (str)
  language to be set

Up